# PROMETRY

## A library for calculating protein geometry parameters with criteria-based searches.

---

To install from [pypi](https://pypi.org/project/prometry/) please run  
```pip install prometry ```

---

Use of the library is demonstrated at [ra-box/prometry](https://ra-box.streamlit.app/prometry)

---

Github page: https://github.com/RachelAlcraft/prometry

Please raise issues: https://github.com/RachelAlcraft/prometry/issues

---




